@@ -20,8 +20,8 @@
 #include <MessageCore/NodeHelper>
 
 #include <QTest>
+#include <cstdlib>
 #include <gpgme++/keylistresult.h>
-#include <stdlib.h>
 
 using namespace MessageComposer;
 
@@ -169,7 +169,7 @@ void ComposerTestUtil::verifySignatureAndEncryption(KMime::Content *content,
                                                     const QByteArray &origContent,
                                                     Kleo::CryptoMessageFormat f,
                                                     bool withAttachment,
-                                                    bool combind)
+                                                    bool combined)
 {
     Q_UNUSED(withAttachment)
     // store it in a KMime::Message, that's what OTP needs
@@ -191,12 +191,11 @@ void ComposerTestUtil::verifySignatureAndEncryption(KMime::Content *content,
         otp.parseObjectTree(resultMessage.data());
         QCOMPARE(nh->encryptionState(resultMessage.data()), MimeTreeParser::KMMsgFullyEncrypted);
 
-        QVector<KMime::Content *> extra = nh->extraContents(resultMessage.data());
+        QList<KMime::Content *> extra = nh->extraContents(resultMessage.data());
         QCOMPARE(extra.size(), 1);
-        if (combind) {
+        if (combined) {
             QCOMPARE(nh->signatureState(resultMessage.data()), MimeTreeParser::KMMsgFullySigned);
         } else {
-            QVector<KMime::Content *> extra = nh->extraContents(resultMessage.data());
             QCOMPARE(extra.size(), 1);
             QCOMPARE(nh->signatureState(extra[0]), MimeTreeParser::KMMsgFullySigned);
         }
@@ -218,7 +217,7 @@ void ComposerTestUtil::verifySignatureAndEncryption(KMime::Content *content,
         otp.parseObjectTree(resultMessage.data());
         QCOMPARE(nh->encryptionState(resultMessage.data()), MimeTreeParser::KMMsgFullyEncrypted);
 
-        QVector<KMime::Content *> extra = nh->extraContents(resultMessage.data());
+        QList<KMime::Content *> extra = nh->extraContents(resultMessage.data());
         QCOMPARE(extra.size(), 1);
         QCOMPARE(nh->signatureState(extra[0]), MimeTreeParser::KMMsgFullySigned);
     }
