@@ -68,7 +68,7 @@ void EmailAddressResolveJob::setDefaultDomainName(const QString &domainName)
 
 void EmailAddressResolveJob::start()
 {
-    QVector<AliasesExpandJob *> jobs;
+    QList<AliasesExpandJob *> jobs;
 
     if (containsAliases(d->mFrom)) {
         auto job = new AliasesExpandJob(d->mFrom, d->mDefaultDomainName, this);
@@ -186,3 +186,5 @@ QStringList EmailAddressResolveJob::expandedReplyTo() const
 {
     return KEmailAddress::splitAddressList(d->mResultMap.value(QStringLiteral("infoPartReplyTo")).toString());
 }
+
+#include "moc_emailaddressresolvejob.cpp"
