@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2021-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2021-2024 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -46,4 +46,17 @@ void ScamDetectionWhiteListSettingsManager::writeSettings()
     // TODO
 }
 
+QList<ScamDetectionInfo> ScamDetectionWhiteListSettingsManager::scamDetectionInfoList() const
+{
+    return mScamDetectionInfoList;
+}
+
+void ScamDetectionWhiteListSettingsManager::setScamDetectionInfoList(const QList<ScamDetectionInfo> &newScamDetectionInfoList)
+{
+    if (mScamDetectionInfoList != newScamDetectionInfoList) {
+        mScamDetectionInfoList = newScamDetectionInfoList;
+        writeSettings();
+    }
+}
+
 #include "moc_scamdetectionwhitelistsettingsmanager.cpp"
